pub trait ErrorInfo<'s, T, R> {
type Format: Display;
// Required method
fn into_info(&'s self) -> Info<T, R, Self::Format>;
}Expand description
Trait for types which can be used to construct error information.
To call functions expecting this trait, use the wrapper types defined in this module
Token, Range, Format or Static/&'static str
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".